@@ -1,5 +1,5 @@
 // This is a part of rust-encoding.
-// Copyright (c) 2013-2014, Kang Seonghoon.
+// Copyright (c) 2013-2015, Kang Seonghoon.
 // See README.md and LICENSE.txt for details.
 
 //! Internal utilities.
@@ -7,7 +7,9 @@
 #![macro_escape]
 
 use std::{str, mem};
+use std::borrow::IntoCow;
 use std::default::Default;
+use std::num::ToPrimitive;
 use types;
 
 /// Unchecked conversion to `char`.
@@ -143,7 +145,7 @@ macro_rules! stateful_decoder(
         #[allow(non_snake_case)]
         mod $stmod {
             pub use self::State::*;
-            #[deriving(PartialEq,Clone,Copy)]
+            #[derive(PartialEq,Clone,Copy)]
             pub enum State {
                 $inist,
                 $(
